// Copyright 2024 Google LLC All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

variable "project" {
  description = "GCP project to deploy the Mainframe Connector service."
  type        = string
}

variable "service_account" {
  description = <<-EOT
  The service account email to use for the Mainframe Connector service.
  e.g. mainframe-connector@my-project.iam.gserviceaccount.com
  EOT
  type        = string
}

variable "region" {
  description = "GCP region to deploy the Mainframe Connector service."
  type        = string
  default     = "us-central1"
}

variable "debug" {
  description = "Turn on debug logging."
  type        = bool
  default     = false
}

variable "name" {
  description = "Name to use. This should be set if you intend to deploy multiple instances of Mainframe Connector in the same GCP project."
  type        = string
}

variable "release" {
  description = "Mainframe Connector release to use. Do not change unless you know what you are doing."
  type        = string
  default     = "9381f5e0058676bf95cc97c64b07ef5ca068d8f9623677d3e00505ea2f992864"
}

variable "container_registry" {
  description = "Container registry containing the Mainframe Connector image. Can be set if using a container registry mirror."
  type        = string
  default     = "us-docker.pkg.dev/migrate-modernize-public/mainframe-connector-prod/mainframe-connector@sha256"
}

variable "additional_labels" {
  description = "Additional labels to add to created resources where applicable."
  type        = map(string)
  default     = {}
}

variable "min_instances_num" {
  description = <<-EOT
  Minimum number of Mainframe Connector instances.
  Setting to 0 will reduce cost but may increase latency for some commands.
  See https://cloud.google.com/run/docs/about-instance-autoscaling for more information.
  EOT
  type        = number
  default     = 1
}

variable "max_instances_num" {
  description = <<-EOT
  Maximum number of Mainframe Connector instances.
  See https://cloud.google.com/run/docs/about-instance-autoscaling for more information.
  EOT
  type        = number
  default     = 50
}

variable "memory_limit" {
  description = <<-EOT
  The maximum amount of memory the service can use.
  More information at https://cloud.google.com/run/docs/configuring/services/memory-limits#terraform
  EOT
  type        = string
  default     = "32Gi"
}

variable "cpu_limit" {
  description = <<-EOT
https://cloud.google.com/run/docs/configuring/services/cpu
  EOT
  type        = string
  default     = "8"
}

variable "ingress" {
  description = <<-EOT
  Ingress policy for the Mainframe Connector service.
  For information about ingress policies, see
  https://cloud.google.com/run/docs/securing/ingress.
  For valid annotation values and descriptions, see
  https://registry.terraform.io/providers/hashicorp/google/latest/docs/resources/cloud_run_v2_service#ingress.
  EOT
  type        = string
  default     = "INGRESS_TRAFFIC_INTERNAL_ONLY"
}

variable "vpc_access" {
  description = <<-EOT
  VPC Access configuration to use for this Task. For more information, visit https://cloud.google.com/run/docs/configuring/connecting-vpc.
  Structure is documented at https://registry.terraform.io/providers/hashicorp/google/5.17.0/docs/resources/cloud_run_v2_service#nested_vpc_access.
  EOT

  type = object({
    connector : string,
    egress : string,
    network_interfaces : object({
      network : string,
      subnetwork : string,
      tags : list(string),
    })
  })
  default = null
}

variable "custom_audiences" {
  description = <<-EOT
  One or more custom audiences that you want this service to support. Specify each custom audience as the full URL in a string.
  The custom audiences are encoded in the token and used to authenticate requests.
  For more information, see https://cloud.google.com/run/docs/configuring/custom-audiences.
  EOT
  type        = list(string)
  default     = []
}

variable "max_instance_request_concurrency" {
  description = "Sets the maximum number of requests that each serving instance can receive."
  type        = number
  default     = 10
}

variable "client_id" {
  description = "A unique identifier used for analytics."
  type    = string
  default = ""
}
